---
title: <span class="badge object-type-scalar"></span> PSI
---
# <span class="badge object-type-scalar"></span> PSI

Pressure: PSI

## Definition

```python
# Pressure: PSI
PSI: typing.Literal["pressurepsi"] = "pressurepsi"
```
